camelot.camelot.types.Code

Package camelot :: Package camelot :: Package types :: Class Code |
[hide private]
[frames] | no frames]

# Class Code

source code

Sqlalchemy column type to store codes

This column type accepts and returns a list of strings and stores them as a string joined with points.

eg: ['08', 'AB'] is stored as 08.AB

Instance Methods | [hide private]
__init__(self, parts, **kwargs) | source code
bind_processor(self, dialect) | source code
result_processor(self, dialect) | source code

Class Variables | [hide private]
| impl = `types.Unicode`

Method Details | [hide private]

### __init__(self, parts, **kwargs) (Constructor) | source code
Parameters: `parts` - a list of input masks specifying the mask for each part, eg ['99', 'AA'], for valid input masks, see the docs of qlineedit